@@ -16,4 +16,4 @@ class LabeledRadioButtonGroup(LabeledContainer):
       LabeledContainer._inflateChildren(self)
       
       for index, proxy in enumerate(self._baseContainerChildren.values()):
-         proxy.value.configure(value = index, variable = self.value)
+         proxy.value.configure(value = index, variable = self.getRawValue())
